@@ -4,6 +4,7 @@
 #define BUILDING_XYLIB
 #include "chiplot.h"
 
+#include <cstdlib>
 #include "util.h"
 
 using namespace std;
@@ -16,7 +17,7 @@ const FormatInfo ChiPlotDataSet::fmt_info(
     "ChiPLOT data",
     "chi",
     false,                      // whether binary
-    true,                       // whether has multi-blocks
+    false,                      // whether has multi-blocks
     &ChiPlotDataSet::ctor,
     &ChiPlotDataSet::check
 );
@@ -35,12 +36,12 @@ bool ChiPlotDataSet::check(istream &f, string*)
     // check 5. line
     getline(f, line);
     const char* p = line.c_str();
-    strtod(p, &endptr); // return value ignored intentionally
+    (void) strtod(p, &endptr); // return value ignored intentionally
     if (endptr == p)
         return false;
     while (isspace(*p) || *p == ',')
         ++p;
-    strtod(p, &endptr); // return value ignored intentionally
+    (void) strtod(p, &endptr); // return value ignored intentionally
     if (endptr == p)
         return false;
     return true;
@@ -99,7 +100,7 @@ string trim_label(string const& str)
     return str.substr(first, last - first + 1);
 }
 
-void ChiPlotDataSet::load_data(std::istream &f)
+void ChiPlotDataSet::load_data(std::istream &f, const char*)
 {
     string graph_title = trim_label(read_line(f));
     string x_label = trim_label(read_line(f));
