@@ -354,12 +354,12 @@ LoopValue::LoopValue(int kind_, string const& s)
     val = my_strtod(val_s);
     int ierr = my_strtol(err_s);
     string::size_type dot_pos = val_s.find('.');
-	if (dot_pos == string::npos)
-		err = ierr;
-	else {
+    if (dot_pos == string::npos) {
+        err = ierr;
+    } else {
         int frac_len = (int) (val_s.size() - dot_pos - 1);
-		err = ierr * pow(10., -frac_len);
-	}
+        err = ierr * pow(10., -frac_len);
+    }
 }
 
 struct DatasetActions
@@ -466,10 +466,11 @@ template <typename IteratorT>
 void t_on_loop_finish::operator()(IteratorT, IteratorT) const
 {
     int ncol = (int) da.loop_tags.size();
+    if (ncol == 0)
+        return;
     int nrow = (int) da.loop_values.size() / ncol;
-    if (ncol == 0 || nrow == 0)
+    if (nrow == 0)
         return;
-    vector<VecColumn*> cols;
     for (int i = 0; i < ncol; ++i) {
         string const& name = da.loop_tags[i];
         if (!is_pd_data_tag(name))
@@ -515,7 +516,7 @@ void t_on_loop_finish::operator()(IteratorT, IteratorT) const
 
 } // anonymous namespace
 
-void PdCifDataSet::load_data(std::istream &f)
+void PdCifDataSet::load_data(std::istream &f, const char*)
 {
     // read file into vector<char>
     f.unsetf(ios::skipws);
@@ -530,8 +531,8 @@ void PdCifDataSet::load_data(std::istream &f)
     CifGrammar<DatasetActions> p(actions);
     parse_info<vector<char>::const_iterator> info =
         parse(vec.begin(), vec.end(), p);
-    format_assert(this, info.full,
-                  "Parse error at character " + S(info.stop - vec.begin()));
+    int stop = info.stop - vec.begin();
+    format_assert(this, info.full, "Parse error at character " + S(stop));
     int n = (int) actions.block_list.size();
     if (n == 0)
         throw RunTimeError("pdCIF file was read, "
