@@ -3,6 +3,8 @@
 
 #define BUILDING_XYLIB
 #include "riet7.h"
+
+#include <cstdlib>
 #include "util.h"
 
 using namespace std;
@@ -13,7 +15,7 @@ namespace xylib {
 
 const FormatInfo Riet7DataSet::fmt_info(
     "riet7",
-    "RIET7/ILL_D1A5/PSI_DMC DAT",
+    "RIET7/LHPM/PSI_DMC",
     "dat",
     false,                      // whether binary
     false,                      // whether has multi-blocks
@@ -45,7 +47,7 @@ bool Riet7DataSet::check(istream &f, string*)
         startptr = endptr;
         double step = strtod(startptr, &endptr);
         startptr = endptr;
-        double stop = strtod(endptr, &endptr);
+        double stop = strtod(startptr, &endptr);
         double dcount = (stop - start) / step + 1;
         int count = iround(dcount);
         if (count < 4 || fabs(count - dcount) > 1e-2)
@@ -58,7 +60,7 @@ bool Riet7DataSet::check(istream &f, string*)
     return false;
 }
 
-void Riet7DataSet::load_data(std::istream &f)
+void Riet7DataSet::load_data(std::istream &f, const char*)
 {
     Block *blk = read_ssel_and_data(f, 5);
     format_assert(this, blk != NULL);
