@@ -63,7 +63,7 @@ and "*STEP" included).The data body of one group begins after "*COUNT=XXX").
 *EOF
 ///////////////////////////////////////////////////////////////////////////////
 */
-void RigakuDataSet::load_data(std::istream &f)
+void RigakuDataSet::load_data(std::istream &f, const char*)
 {
     Block *blk = NULL;
     VecColumn *ycol = NULL;
@@ -95,7 +95,7 @@ void RigakuDataSet::load_data(std::istream &f)
             else { // meta key-value pair
                 string key, val;
                 // parse "*KEY = VALUE"
-                str_split(line.substr(1), "=", key, val);
+                str_split(line.substr(1), '=', key, val);
                 if (key == "START")
                     start = my_strtod(val);
                 else if (key == "STEP")
@@ -117,6 +117,7 @@ void RigakuDataSet::load_data(std::istream &f)
             ycol->add_values_from_str(line, ',');
         }
     }
+    format_assert(this, ycol == NULL && blk == NULL, "*BEGIN without *END");
     format_assert(this, grp_cnt != 0, "no GROUP_COUNT attribute given");
     format_assert(this, grp_cnt == get_block_count(),
                   "block count different from expected");
