@@ -4,12 +4,14 @@
 #ifndef XYLIB_UTIL_H_
 #define XYLIB_UTIL_H_
 
+#include <cassert>
+#include <cmath>    // floor
+#include <cstdio>   // snprintf
+#include <cstring>  // memcpy
+#include <fstream>
+#include <memory>   // auto_ptr/unique_ptr
 #include <string>
 #include <vector>
-#include <stdexcept>
-#include <fstream>
-#include <cassert>
-#include <cmath>
 
 #include "xylib.h"
 
@@ -22,10 +24,12 @@ namespace xylib { namespace util {
 void le_to_host(void *ptr, int size);
 
 unsigned int read_uint32_le(std::istream &f);
+int read_int32_le(std::istream &f);
 unsigned int read_uint16_le(std::istream &f);
 int read_int16_le(std::istream &f);
 float read_flt_le(std::istream &f);
 double read_dbl_le(std::istream &f);
+int read_int32_be(std::istream &f);
 
 char read_char(std::istream &f);
 std::string read_string(std::istream &f, unsigned len);
@@ -33,7 +37,8 @@ std::string read_string(std::istream &f, unsigned len);
 template<typename T>
 T from_le(const char* p)
 {
-    T val = *reinterpret_cast<const T*>(p);
+    T val;
+    std::memcpy(&val, p, sizeof(val));
     le_to_host(&val, sizeof(val));
     return val;
 }
@@ -41,14 +46,18 @@ T from_le(const char* p)
 double from_pdp11(const unsigned char* p);
 
 std::string str_trim(std::string const& str);
-void str_split(std::string const& line, std::string const& sep,
+void str_split(std::string const& line, char sep,
                std::string &key, std::string &val);
-bool str_startwith(const std::string &str_src, const std::string &ss);
+inline bool str_startwith(const std::string &str, const std::string &prefix) {
+    return str.compare(0, prefix.size(), prefix) == 0;
+}
+
 std::string str_tolower(const std::string &str);
 bool has_word(const std::string &sentence, const std::string &word);
 
 std::string read_line(std::istream &is);
 bool get_valid_line(std::istream &is, std::string &line, char comment_char);
+std::istream& getline_with_any_ending(std::istream& is, std::string& t);
 
 void skip_whitespace(std::istream &f);
 Column* read_start_step_end_line(std::istream& f);
@@ -57,11 +66,12 @@ Block* read_ssel_and_data(std::istream &f, int max_headers=0);
 long my_strtol(const std::string &str);
 double my_strtod(const std::string &str);
 
-inline bool is_numeric(int c)
-    { return isdigit(c) || c=='+' ||  c=='-' || c=='.'; }
+inline bool is_numeric(int c) {
+    return (c >= '0' && c <= '9') || c=='+' ||  c=='-' || c=='.';
+}
 
 /// Round real to integer.
-inline int iround(double d) { return static_cast<int>(floor(d+0.5)); }
+inline int iround(double d) { return static_cast<int>(std::floor(d+0.5)); }
 
 /// S() converts any type to string
 template <typename T, int N>
@@ -71,7 +81,7 @@ std::string format1(const char* fmt, T t)
 #ifdef _MSC_VER
     _snprintf(buffer, N, fmt, t);
 #else
-    snprintf(buffer, N, fmt, t);
+    std::snprintf(buffer, N, fmt, t);
 #endif
     buffer[N-1] = '\0';
     return std::string(buffer);
@@ -82,6 +92,7 @@ inline std::string S(const char *k) { return std::string(k); }
 inline std::string S(const char k) { return std::string(1, k); }
 inline std::string S(int n) { return format1<int, 16>("%d", n); }
 inline std::string S(long n) { return format1<long, 21>("%ld", n); }
+inline std::string S(long long n) { return format1<long long, 24>("%lld", n); }
 // unsigned and size_t can be the same as type (e.g. MinGW on Windows)
 inline std::string Su(unsigned n) { return format1<unsigned, 16>("%u", n); }
 inline std::string S(size_t n)
@@ -121,6 +132,11 @@ inline void format_assert(DataSet const* ds, bool condition,
                           + (comment.empty() ? comment : "; " + comment));
 }
 
+#if (defined(__GNUC__) && !defined(__MINGW32__)) || defined(__clang)
+__attribute__((format(printf, 1, 2)))
+#endif
+void warn(const char *fmt, ...);
+
 class ColumnWithName : public Column
 {
 public:
@@ -193,6 +209,16 @@ public:
     }
 };
 
+/// SK: Add declaration of swapping of signed integer binaries
+int swap_int32(int val);
+
+#if __cplusplus-0 < 201103L
+typedef std::auto_ptr<Block> AutoPtrBlock;
+#else
+typedef std::unique_ptr<Block> AutoPtrBlock;
+#endif
+
+
 } } // namespace xylib::util
 
 #endif // XYLIB_UTIL_H_
