@@ -15,7 +15,7 @@ namespace xylib {
 
 const FormatInfo WinspecSpeDataSet::fmt_info(
     "spe",
-    "Princeton Instruments WinSpec",
+    "PI WinSpec SPE",
     "spe",
     true,                       // whether binary
     true,                       // whether has multi-blocks
@@ -24,7 +24,7 @@ const FormatInfo WinspecSpeDataSet::fmt_info(
 );
 
 enum {
-    SPE_HEADER_SIZE = 4100,   // fixed binary header size
+    SPE_HEADER_SIZE = 4100  // fixed binary header size
 };
 
 /* datatypes of DATA point in spe_file */
@@ -32,7 +32,7 @@ enum spe_dt {
     SPE_DATA_FLOAT = 0,     // size 4
     SPE_DATA_LONG  = 1,     // size 4
     SPE_DATA_INT   = 2,     // size 2
-    SPE_DATA_UINT  = 3,     // size 2
+    SPE_DATA_UINT  = 3      // size 2
 };
 
 // Calibration structure in SPE format.
@@ -65,7 +65,7 @@ struct spe_calib {
 bool WinspecSpeDataSet::check(istream &f, string*) {
     // make sure file size > 4100 (data begins after a 4100-byte header)
     f.seekg(-1, ios_base::end);
-    long file_sz = f.tellg();
+    streampos file_sz = f.tellg();
     if (file_sz <= 4100) {
         return false;
     }
@@ -80,7 +80,7 @@ bool WinspecSpeDataSet::check(istream &f, string*) {
 }
 
 
-void WinspecSpeDataSet::load_data(std::istream &f)
+void WinspecSpeDataSet::load_data(std::istream &f, const char*)
 {
     // only read necessary params from file header
     f.ignore(42);
@@ -124,7 +124,7 @@ void WinspecSpeDataSet::load_data(std::istream &f)
                     y = read_flt_le(f);
                     break;
                 case SPE_DATA_LONG:
-                    y = read_uint32_le(f);
+                    y = read_int32_le(f);
                     break;
                 case SPE_DATA_INT:
                     y = read_int16_le(f);
@@ -146,7 +146,7 @@ void WinspecSpeDataSet::load_data(std::istream &f)
 
 Column* WinspecSpeDataSet::get_calib_column(const spe_calib *calib, int dim)
 {
-    format_assert(this, calib->polynom_order <= 6, "bad polynom header");
+    format_assert(this, calib->polynom_order < 6, "bad polynom header");
 
     if (!calib->calib_valid)    //use idx as X instead
         return new StepColumn(0, 1);
@@ -185,4 +185,3 @@ void WinspecSpeDataSet::read_calib(istream &f, spe_calib &calib)
 
 } // end of namespace xylib
 
-
